@@ -10,12 +10,14 @@ class cd:
 
     >>> import os
     >>> from pathlib import Path
+    >>> import subprocess
     >>> from pyfeasst import cd
-    >>> with cd.cd("~/pyfeasst"): print(Path(os.getcwd()).name)
-    pyfeasst
+    >>> subprocess.call("mkdir -p tmp", shell=True, executable='/bin/bash')
+    >>> with cd.cd("tmp"): print(Path(os.getcwd()).name)
+    tmp
     """
-    def __init__(self, newPath):
-        self._new_path = os.path.expanduser(newPath)
+    def __init__(self, new_path):
+        self._new_path = os.path.expanduser(new_path)
         self._saved_path = None
 
     def __enter__(self):
